@@ -9,6 +9,7 @@ struct SentimentScorerOnegrams : public RcppParallel::Worker {
   const std::unordered_map< std::string, std::vector< double> > lexiconMap;
   const std::string how;
   const int nL;
+  const int N;
   std::unordered_map< int, std::unordered_map< std::string, double > > frequencyMap;
   std::unordered_map< std::string, double > inverseFrequencyMap;
   const bool isFreqWeighting;
@@ -20,11 +21,12 @@ struct SentimentScorerOnegrams : public RcppParallel::Worker {
                           const std::unordered_map< std::string, std::vector< double > > lexiconMap,
                           const std::string how,
                           int nL,
+                          int N,
                           std::unordered_map< int, std::unordered_map< std::string, double > > frequencyMap,
                           std::unordered_map< std::string, double > inverseFrequencyMap,
                           const bool isFreqWeighting,
                           Rcpp::NumericMatrix sentScores)
-    : texts(texts), lexiconMap(lexiconMap), how(how), nL(nL), frequencyMap(frequencyMap), inverseFrequencyMap(inverseFrequencyMap), isFreqWeighting(isFreqWeighting), sentScores(sentScores) {}
+    : texts(texts), lexiconMap(lexiconMap), how(how), nL(nL), N(N), frequencyMap(frequencyMap), inverseFrequencyMap(inverseFrequencyMap), isFreqWeighting(isFreqWeighting), sentScores(sentScores) {}
 
   void operator()(std::size_t begin, std::size_t end) {
 
@@ -35,6 +37,7 @@ struct SentimentScorerOnegrams : public RcppParallel::Worker {
       std::vector< double > nPolarized(nL, 0.0);
       double normalizer = 0.0;
       int nTokens = tokens.size();
+      int nPuncts = 0;
       std::vector< std::vector< double > > tokenScores(nTokens,std::vector< double >(nL, 0.0));
       std::vector< double > tokenWeights(nTokens, 0.0);
       std::vector< double > tokenShifters(nTokens, 1.0);
@@ -57,11 +60,11 @@ struct SentimentScorerOnegrams : public RcppParallel::Worker {
         if (lexiconMap.find(token) != lexiconMap.end()) {
           tokenScores[j] = lexiconMap.at(token); // get value of token for each lexico
         }
-        if (how != "proportional"  && how != "counts" && how != "squareRootCounts") {
-          update_token_weights(tokenWeights, normalizer, nPolarized, j, nTokens, how, nL, tokenScores, tokenFrequency, tokenInverseFrequency, maxTokenFrequency); //step 3 and 4: get token Weights
+        if (how != "proportional" && how != "counts" && how != "proportionalSquareRoot") {
+          update_token_weights(tokenWeights, normalizer, nPolarized, j, nTokens, how, nL, tokenScores, tokenFrequency, tokenInverseFrequency, maxTokenFrequency, N);
         }
       }
-      update_token_scores(scores, tokenScores, normalizer, nPolarized, tokenShifters, tokenWeights, nL, nTokens, how);
+      update_token_scores(scores, tokenScores, normalizer, nPolarized, tokenShifters, tokenWeights, nL, nTokens, how, nPuncts);
 
       sentScores(i, 0) = nTokens;
       for (int m = 0; m < nL; m++) {
